// Header File
// Created 30/09/2006; 12:15:43 p.m.

//propiedades reune funciones para el calculos de propiedades termodinmicas en diferentes fases
//termodinmicas del agua
//Copyright (C) 2006  David F. Suescun R. daisukeing@gmail.com
//
//This program is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either version 2
//of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

//Funcin para hallar las propiedades termodinmicas de agua lquida comprimida (p,T)
float liq_prop(float p,float T,float calcvcp)
{
	float pii=0,tau=0,f1=0,f1pii=0,f1piipii=0,f1tau=0,f1tautau=0,f1piitau=0;
/*	p=p1hs(h,s);
	T=T1h(p,h);*/
	pii=p/(16.53);
	tau=(1386)/T;
	f1=ff1(pii,tau);
	f1pii=ff1pii(pii,tau);
	f1tau=ff1tau(pii,tau);
	push_END_TAG ();
	//Si se desea calcular Cv y Cp o no
	if (calcvcp==1)
	{
	f1tautau=ff1tautau(pii,tau);
	f1piitau=ff1piitau(pii,tau);
	f1piipii=ff1piipii(pii,tau);
	push_Float (cp1(tau,f1tautau));
	push_Float (cv1(tau,f1tautau,f1pii,f1piitau,f1piipii));
	}
	push_Float (s1(tau,f1,f1tau));
	push_Float (h1(T,tau,f1tau));
	push_Float (u_1(T,pii,tau,f1pii,f1tau));
	push_Float (v1(p,T,pii,f1pii)/1000);
	push_Float (T);
	push_Float (p);
	push_LIST_TAG ();
	return (0.0);
}


//Funcin para hallar las propiedades termodinmicas del vapor de agua sobrecalentado (p,T)
float vap_prop(float p,float T,float calcvcp)
{
	float pii=0,tau=0,f2o=0,f2opii=0,f2opiipii=0,f2otau=0,f2otautau=0,f2opiitau=0,f2r=0,f2rpii=0,f2rpiipii=0,f2rtau=0,f2rtautau=0,f2rpiitau=0,f2=0,f2pii=0,f2piipii=0,f2tau=0,f2tautau=0,f2piitau=0;
	pii=p;
	tau=(540)/(T);
	f2opiipii=ff2opiipii(pii);
	f2piipii=ff2piipii(f2opiipii,f2rpiipii);
	f2o=ff2o(pii,tau);
	f2opii=ff2opii(pii);
	f2otau=ff2otau(tau);
	f2r=ff2r(pii,tau);
	f2rpii=ff2rpii(pii,tau);
	f2rtau=ff2rtau(pii,tau);
	f2=ff2(f2o,f2r);
	f2pii=ff2pii(f2opii,f2rpii);
	f2tau=ff2tau(f2otau,f2rtau);
	push_END_TAG ();
	//Si se desea calcular Cv y Cp o no
	if (calcvcp==1)
	{
		f2rpiipii=ff2rpiipii(pii,tau);
		f2opiitau=ff2opiitau(pii,tau);
		f2rpiitau=ff2rpiitau(pii,tau);
		f2piitau=ff2piitau(f2opiitau,f2rpiitau);
		f2otautau=ff2otautau(tau);
		f2rtautau=ff2rtautau(pii,tau);
		f2tautau=ff2tautau(f2otautau,f2rtautau);
		push_Float (cp2(tau,f2tautau));
		push_Float (cv2(pii,tau,f2tautau,f2rpii,f2rpiitau,f2rpiipii));
	}
	push_Float (s2(tau,f2tau,f2));
	push_Float (h2(T,tau,f2tau));
	push_Float (u_2(T,pii,tau,f2tau,f2pii));
	push_Float (v2(p,T,pii,f2pii)/1000);
	push_Float (T);
	push_Float (p);
	push_LIST_TAG ();
	return (0.0);
}


//Funcin para hallar las propiedades termodinmicas de agua Satutada (equilibrio lquido-vapor) (p,T,x)
float h2osatpt(float p,float T,float xhs)
{
	float pii=0,tau=0,vg=0,vfg=0,vf=0,u=0,v=0,h=0,s=0,uf=0,ufg=0,ug=0,hf=0,hfg=0,hg=0,sf=0,sfg=0,sg=0,f2o=0,f2opii=0,f2opiipii=0,f2otau=0,f2r=0,f2rpii=0,f2rpiipii=0,f2rtau=0,f2=0,f2pii=0,f2piipii=0,f2tau=0,f1=0,f1pii=0,f1tau=0;
	//Fase Vapor
	pii=p;
	tau=(540)/(T);
	f2opiipii=ff2opiipii(pii);
	f2piipii=ff2piipii(f2opiipii,f2rpiipii);
	f2o=ff2o(pii,tau);
	f2opii=ff2opii(pii);
	f2otau=ff2otau(tau);
	f2r=ff2r(pii,tau);
	f2rpii=ff2rpii(pii,tau);
	f2rtau=ff2rtau(pii,tau);
	f2=ff2(f2o,f2r);
	f2pii=ff2pii(f2opii,f2rpii);
	f2tau=ff2tau(f2otau,f2rtau);
	sg=s2(tau,f2tau,f2);
	hg=h2(T,tau,f2tau);
	ug=u_2(T,pii,tau,f2tau,f2pii);
	vg=v2(p,T,pii,f2pii)/1000;
	//Fase lquida
	pii=p/(16.53);
	tau=(1386)/T;
	f1=ff1(pii,tau);
	f1pii=ff1pii(pii,tau);
	f1tau=ff1tau(pii,tau);
	//Si se desea calcular Cv y Cp o no
	sf=s1(tau,f1,f1tau);
	hf=h1(T,tau,f1tau);
	uf=u_1(T,pii,tau,f1pii,f1tau);
	vf=v1(p,T,pii,f1pii)/1000;
	//Volumen
	vfg=vg-vf;
	//Energa Interna
	ufg=ug-uf;
	//Entalpa
	hfg=hg-hf;
	//Entropa
	sfg=sg-sf;
	push_END_TAG ();
	push_Float (sg);
	push_Float (sfg);
	push_Float (sf);
	push_Float (hg);
	push_Float (hfg);
	push_Float (hf);
	push_Float (ug);
	push_Float (ufg);
	push_Float (uf);
	push_Float (vg);
	push_Float (vfg);
	push_Float (vf);
	//De existir Calidad de Vapor
	if (xhs>=0 && xhs<=1)
	{
		v=vf+xhs*vfg;
		h=hf+xhs*hfg;
		s=sf+xhs*sfg;
		u=uf+xhs*ufg;
		push_Float (s);
		push_Float (h);
		push_Float (u);
		push_Float (v);
		push_Float (xhs);
	}
	push_Float (T);
	push_Float (p);
	push_LIST_TAG ();
	return (0.0);
}

//Funcin para hallar las propiedades termodinmicas de agua Satutada (equilibrio lquido-vapor) (h,s)
float h2osaths(float h,float s)
{
	float Tcal=0,Tcal1=0,Tcal2=0,pcal=0,xhs=0;
	Tcal=Tsaths(h,s);	
	if (273.14>=Tcal || Tcal>=623.1766)
	{
		Tcal2=T2hs(h,s);
		if (273.14<=Tcal2 && Tcal2<=1073.176)
		{
			push_zstr ("Vapor de H2O Sobrecalentado1");
			return (1.0);
		}
		Tcal1=T1hs(h,s);
		if (273.14<=Tcal1 && Tcal1<=623.1766)
		{
			push_zstr ("Agua lquida Comprimida1");
			return (1.0);
		}
		push_zstr ("Regin no soportada");
		return (1.0);
	}
	Tcal2=T2hs(h,s);
	if (273.14<=Tcal2 && Tcal2<=1073.176)
	{
		if (Tcal2-Tcal>0.9 || Tcal-Tcal2>0.9)
		{
			push_zstr ("Vapor de H2O Sobrecalentado2");
			return (1.0);
		}
	}
	Tcal1=T1hs(h,s);
	if (273.14<=Tcal1 && Tcal1<=623.1766)
	{
		if (Tcal1>(Tcal+2))
		{
			push_zstr ("Agua lquida Comprimida2");
			return (1.0);
		}
		else
		{
			Tcal=Tcal1;
		}
	}
	pcal=psat(Tcal);
	xhs=xpt(h,pcal,Tcal);
	if (xhs>1) xhs=1;
	if (xhs<0) xhs=0; 
	h2osatpt(pcal,Tcal,xhs);
	return (0.0);
}